@@ -22,14 +22,15 @@ G_BEGIN_DECLS
  * loader = gly_loader_new (file);
  * image = gly_loader_load (loader, NULL);
  * if (image)
- * {
- *   frame = gly_image_next_frame (image, NULL);
- *   if (frame) {
- *     texture = gly_gtk_frame_get_texture (frame);
- *     printf ("Image height: %d\n", gdk_texture_get_height (texture));
- *     image_widget = gtk_image_new_from_paintable (GDK_PAINTABLE (texture));
+ *   {
+ *     frame = gly_image_next_frame (image, NULL);
+ *     if (frame)
+ *       {
+ *         texture = gly_gtk_frame_get_texture (frame);
+ *         g_print ("Image height: %d\n", gdk_texture_get_height (texture));
+ *         image_widget = gtk_image_new_from_paintable (GDK_PAINTABLE (texture));
+ *       }
  *   }
- * }
  * ```
  *
  * Since: 2.0
@@ -250,7 +251,7 @@ void gly_loader_get_mime_types_async(
  *
  * Since: 2.0
  */
-GStrv *gly_loader_get_mime_types_finish(
+GStrv gly_loader_get_mime_types_finish(
     GAsyncResult *result,
     GError **error);
 
@@ -378,6 +379,21 @@ void gly_frame_request_set_scale(GlyFrameRequest *frame_request,
                                  uint32_t width,
                                  uint32_t height);
 
+/**
+ * gly_frame_request_set_loop_animation:
+ * @frame_request:
+ * @loop_animation:
+ *
+ * Controls if first frame is returned after last frame
+ *
+ * By default, this option is set to `TRUE`, returning the first frame, if
+ * the previously requested frame was the last frame.
+ *
+ * Since: 2.0.1
+ */
+void gly_frame_request_set_loop_animation(GlyFrameRequest *frame_request,
+                                          gboolean loop_animation);
+
 /**************** GlyImage ****************/
 
 /**
@@ -534,7 +550,7 @@ uint32_t gly_image_get_height(GlyImage *image);
  *
  * Since: 2.0
  **/
-const gchar *
+gchar *
 gly_image_get_metadata_key_value(GlyImage *image,
                                  const gchar *key);
 
@@ -767,8 +783,9 @@ GlyCicp *gly_frame_get_color_cicp(GlyFrame *frame);
 
 /**
  * GlyLoaderError:
- * @GLY_LOADER_ERROR_FAILED: Generic type for all other errors.
- * @GLY_LOADER_ERROR_UNKNOWN_IMAGE_FORMAT: Unknown image format.
+ * @GLY_LOADER_ERROR_FAILED:
+ * @GLY_LOADER_ERROR_UNKNOWN_IMAGE_FORMAT:
+ * @GLY_LOADER_ERROR_NO_MORE_FRAMES:
  *
  * Errors that can appear while loading images.
  *
@@ -776,8 +793,30 @@ GlyCicp *gly_frame_get_color_cicp(GlyFrame *frame);
  */
 typedef enum
 {
+    /**
+     * GLY_LOADER_ERROR_FAILED:
+     *
+     * Generic type for all other errors.
+     *
+     * Since: 2.0
+     */
     GLY_LOADER_ERROR_FAILED,
+    /**
+     * GLY_LOADER_ERROR_UNKNOWN_IMAGE_FORMAT:
+     *
+     * Unknown image format.
+     *
+     * Since: 2.0
+     */
     GLY_LOADER_ERROR_UNKNOWN_IMAGE_FORMAT,
+    /**
+     * GLY_LOADER_ERROR_NO_MORE_FRAMES:
+     *
+     * Reached last frame in an animation with [method@FrameRequest.set_loop_animation] to `FALSE`.
+     *
+     * Since: 2.0.1
+     */
+    GLY_LOADER_ERROR_NO_MORE_FRAMES,
 } GlyLoaderError;
 
 /**
